import abc

class Interface1(object):
    __metaclass__ = abc.ABCMeta

    """Pure virtural class for the Bioinformatics Data Interface.
    Every BDI implementation should be a subclass (possibly indirect) of this class.
    """

    def interface_version(self):
        return 0

    @abc.abstractmethod
    def data_version(self):
        pass

    @abc.abstractmethod
    def schema_version(self):
        pass

    @abc.abstractmethod
    def get_tx_exons(self, tx_ac, alt_ac, alt_aln_method):
        pass

    @abc.abstractmethod
    def get_tx_info(self, tx_ac, alt_ac, alt_aln_method):
        pass

    @abc.abstractmethod
    def get_tx_seq(self,ac):
        pass

    @abc.abstractmethod
    def get_tx_for_gene(self, gene):
        pass

    @abc.abstractmethod
    def get_acs_for_protein_seq(seq):
        pass

    @abc.abstractmethod
    def get_gene_info(self, gene):
        pass

    @abc.abstractmethod
    def get_tx_mapping_options(self, tx_ac):
        pass

    @abc.abstractmethod
    def get_tx_identity_info(self, tx_ac):
        pass

## <LICENSE>
## Copyright 2014 BDI Contributors (https://bitbucket.org/invitae/bdi)
## 
## Licensed under the Apache License, Version 2.0 (the "License");
## you may not use this file except in compliance with the License.
## You may obtain a copy of the License at
## 
##     http://www.apache.org/licenses/LICENSE-2.0
## 
## Unless required by applicable law or agreed to in writing, software
## distributed under the License is distributed on an "AS IS" BASIS,
## WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
## See the License for the specific language governing permissions and
## limitations under the License.
## </LICENSE>
